@@ -4,8 +4,8 @@
 __author__ = "Timo Stollenwerk (timo@zmag.de)"
 __license__ = "GNU General Public License (GPL)"
 __revision__ = "$Rev: 257 $"
-__date__ = "$Date: 2008-03-11 22:00:09 +0100 (Di, 11 Mrz 2008) $"
-__URL__ = "$URL: https://svn.zmag.de/svn/python/docbook2sla/trunk/docbook2sla/docbook2sla.py $"
+__date__ = "$Date: 2008-03-11 22:00:09 +0100 (Tue, 11 Mar 2008) $"
+__URL__ = "$URL: http://svn.zmag.de/svn/python/docbook2sla/trunk/docbook2sla/docbook2sla.py $"
 
 import os, sys
 
